@@ -12,6 +12,7 @@ Usage:
          [-q | -v...] [-i] [-g DEF]... [TARGET...]
   kibot [-v...] [-c PLOT_CONFIG] --list
   kibot [-v...] [-b BOARD] [-d OUT_DIR] [-p | -P] --example
+  kibot [-v...] --help-filters
   kibot [-v...] --help-list-outputs
   kibot [-v...] --help-output=HELP_OUTPUT
   kibot [-v...] --help-outputs
@@ -29,6 +30,7 @@ Options:
   -d OUT_DIR, --out-dir OUT_DIR    The output directory [default: .]
   -e SCHEMA, --schematic SCHEMA    The schematic file (.sch)
   -g DEF, --global-redef DEF       Overwrite a global value (VAR=VAL)
+  --help-filters                   List supported filters and details
   --help-list-outputs              List supported outputs
   --help-output HELP_OUTPUT        Help for this particular output
   --help-outputs                   List supported outputs and details
@@ -51,12 +53,11 @@ __license__ = 'GPL v3+'
 __email__ = 'set@ieee.org'
 __url__ = 'https://github.com/INTI-CMNB/KiBot/'
 __status__ = 'stable'
-__version__ = '0.7.0'
+__version__ = '0.8.0'
 
 
 import os
 import sys
-import stat
 import gzip
 import locale
 from glob import glob
@@ -65,50 +66,15 @@ from logging import DEBUG
 # Import log first to set the domain
 from . import log
 log.set_domain('kibot')
+logger = log.init()
 from .gs import (GS)
 from .kiplot import (generate_outputs, load_actions, config_output)
 from .pre_base import (BasePreFlight)
-from .config_reader import (CfgYamlReader, print_outputs_help, print_output_help, print_preflights_help, create_example)
-from .misc import (NO_PCB_FILE, NO_SCH_FILE, EXIT_BAD_ARGS)
+from .config_reader import (CfgYamlReader, print_outputs_help, print_output_help, print_preflights_help, create_example,
+                            print_filters_help)
+from .misc import (NO_PCB_FILE, NO_SCH_FILE, EXIT_BAD_ARGS, W_VARSCH, W_VARCFG, W_VARPCB)
 from .docopt import docopt
 
-logger = None
-has_macro = [
-             'layer',
-             'drill_marks',
-             'fil_base',
-             'fil_generic',
-             'out_any_drill',
-             'out_any_layer',
-             'out_base',
-             'out_bom',
-             'out_dxf',
-             'out_excellon',
-             'out_gerb_drill',
-             'out_gerber',
-             'out_hpgl',
-             'out_ibom',
-             'out_kibom',
-             'out_pcbdraw',
-             'out_pdf',
-             'out_pdf_pcb_print',
-             'out_pdf_sch_print',
-             'out_position',
-             'out_ps',
-             'out_sch_variant',
-             'out_step',
-             'out_svg',
-             'out_svg_sch_print',
-             'pre_check_zone_fills',
-             'pre_drc',
-             'pre_erc',
-             'pre_filters',
-             'pre_ignore_unconnected',
-             'pre_update_xml',
-             'var_base',
-             'var_kibom',
-            ]
-
 
 def list_pre_and_outs(logger, outputs):
     logger.info('Available actions:\n')
@@ -127,11 +93,16 @@ def list_pre_and_outs(logger, outputs):
 def solve_schematic(a_schematic, a_board_file):
     schematic = a_schematic
     if not schematic and a_board_file:
-        sch = os.path.splitext(a_board_file)[0]+'.sch'
+        base = os.path.splitext(a_board_file)[0]
+        sch = base+'.sch'
         if os.path.isfile(sch):
             schematic = sch
+        else:
+            sch = base+'.kicad_sch'
+            if os.path.isfile(sch):
+                schematic = sch
     if not schematic:
-        schematics = glob('*.sch')
+        schematics = glob('*.sch')+glob('*.kicad_sch')
         if len(schematics) == 1:
             schematic = schematics[0]
             logger.info('Using SCH file: '+schematic)
@@ -145,7 +116,7 @@ def solve_schematic(a_schematic, a_board_file):
                     break
             if schematic is None:
                 schematic = schematics[0]
-            logger.warning('More than one SCH file found in current directory.\n'
+            logger.warning(W_VARSCH + 'More than one SCH file found in current directory.\n'
                            '  Using '+schematic+' if you want to use another use -e option.')
     if schematic and not os.path.isfile(schematic):
         logger.error("Schematic file not found: "+schematic)
@@ -167,7 +138,7 @@ def solve_config(a_plot_config):
             logger.info('Using config file: '+plot_config)
         elif len(plot_configs) > 1:
             plot_config = plot_configs[0]
-            logger.warning('More than one config file found in current directory.\n'
+            logger.warning(W_VARCFG + 'More than one config file found in current directory.\n'
                            '  Using '+plot_config+' if you want to use another use -c option.')
         else:
             logger.error('No config file found (*.kibot.yaml), use -c to specify one.')
@@ -198,7 +169,7 @@ def solve_board_file(schematic, a_board_file):
             logger.info('Using PCB file: '+board_file)
         elif len(board_files) > 1:
             board_file = board_files[0]
-            logger.warning('More than one PCB file found in current directory.\n'
+            logger.warning(W_VARPCB + 'More than one PCB file found in current directory.\n'
                            '  Using '+board_file+' if you want to use another use -b option.')
     check_board_file(board_file)
     if board_file:
@@ -223,38 +194,13 @@ def set_locale():
         pass
 
 
-def clean_cache():
-    """ Files that expands macros can't be pre-compiled """
-    here = os.path.abspath(os.path.dirname(__file__))
-    cache = os.path.join(here, '__pycache__')
-    logger.debug('Python cache dir: '+cache)
-    try:
-        if os.path.isdir(cache):
-            for f in has_macro:
-                fnames = glob(os.path.join(cache, f+'.*'))
-                for fname in fnames:
-                    if os.path.isfile(fname):
-                        # Don't remove read-only files
-                        r = os.stat(fname)
-                        if stat.S_IMODE(r.st_mode) & (stat.S_IWUSR | stat.S_IWGRP | stat.S_IWOTH):
-                            logger.debug('Removing '+fname)
-                            os.remove(fname)
-                        else:
-                            raise PermissionError()
-    except PermissionError:
-        logger.warning('Wrong installation, avoid creating Python cache files\n'
-                       'If you are using `pip` to install use the `--no-compile` option:\n'
-                       '$ pip install --no-compile kibot\n')
-
-
 def main():
     set_locale()
     ver = 'KiBot '+__version__+' - '+__copyright__+' - License: '+__license__
     args = docopt(__doc__, version=ver, options_first=True)
 
-    # Create a logger with the specified verbosity
-    global logger
-    logger = log.init(args.verbose, args.quiet)
+    # Set the specified verbosity
+    log.set_verbosity(logger, args.verbose, args.quiet)
     GS.debug_enabled = logger.getEffectiveLevel() <= DEBUG
     GS.debug_level = args.verbose
 
@@ -266,8 +212,6 @@ def main():
         var = redef.split('=')[0]
         GS.global_from_cli[var] = redef[len(var)+1:]
 
-    clean_cache()
-
     # Output dir: relative to CWD (absolute path overrides)
     GS.out_dir = os.path.join(os.getcwd(), args.out_dir)
 
@@ -283,6 +227,9 @@ def main():
     if args.help_preflights:
         print_preflights_help()
         sys.exit(0)
+    if args.help_filters:
+        print_filters_help()
+        sys.exit(0)
     if args.example:
         check_board_file(args.board_file)
         if args.copy_options and not args.board_file:
