@@ -14,14 +14,14 @@ from copy import deepcopy
 from .units import compare_values, comp_match
 from .bom_writer import write_bom
 from .columnlist import ColumnList
-from ..misc import DNF
+from ..misc import DNF, W_FIELDCONF
 from .. import log
 
 logger = log.get_logger(__name__)
 # RV == Resistor Variable or Varistor
 # RN == Resistor 'N'(Pack)
 # RT == Thermistor
-RLC_PREFIX = {'R': 1, 'L': 1, 'C': 1, 'RV': 1, 'RN': 1, 'RT': 1}
+RLC_PREFIX = {'R', 'L', 'C', 'RV', 'RN', 'RT'}
 
 
 def compare_value(c1, c2, cfg):
@@ -190,7 +190,7 @@ class ComponentGroup(object):
 
     def get_refs(self):
         """ Return a list of the components """
-        return " ".join([c.ref for c in self.components])
+        return self.cfg.ref_separator.join([c.ref for c in self.components])
 
     def get_alt_refs(self):
         """ Alternative list of references using ranges """
@@ -215,7 +215,7 @@ class ComponentGroup(object):
             # Config contains variant information, which is different for each component
             # Part can be one of the defined aliases
             if field != self.cfg.fit_field and field != 'part':
-                logger.warning("Field conflict: ({refs}) [{name}] : '{flds}' <- '{fld}' (in {ref})".format(
+                logger.warning(W_FIELDCONF + "Field conflict: ({refs}) [{name}] : '{flds}' <- '{fld}' (in {ref})".format(
                     refs=self.get_refs(),
                     name=field,
                     flds=self.fields[field],
