@@ -8,10 +8,11 @@ Macros to make the output plug-ins cleaner.
 """
 from .gs import GS  # noqa: F401
 from ast import (Assign, Name, Attribute, Expr, Num, Str, NameConstant, Load, Store, UnaryOp, USub,
-                 ClassDef, Call, ImportFrom, alias, copy_location)
+                 ClassDef, Call, ImportFrom, copy_location, alias)
+from .mcpyrate import unparse
 
 
-def document(sentences, to_source, **kw):
+def document(sentences, **kw):
     """ This macro takes literal strings and converts them into:
         _help_ID = type_hint+STRING
         where:
@@ -61,7 +62,7 @@ def document(sentences, to_source, **kw):
                 type_hint = '[boolean={}]'.format(str(value.value).lower())
             elif isinstance(value, Attribute):
                 # Used for the default options. I.e. GS.def_global_option
-                val = eval(to_source(value))
+                val = eval(unparse(value))
                 if isinstance(val, bool):
                     # Not used yet
                     type_hint = '[boolean={}]'.format(str(val).lower())  # pragma: no cover
@@ -76,8 +77,12 @@ def document(sentences, to_source, **kw):
                 target = Attribute(value=Name(id='self', ctx=Load()), attr=doc_id, ctx=Store())
             else:  # pragma: no cover
                 target = Name(id=doc_id, ctx=Store())
-            sentences[n] = Assign(targets=[target], value=Str(s=type_hint+s.value.s.rstrip()+post_hint))
+            # Reuse the s.value Str
+            help_str = s.value
+            help_str.s = type_hint+s.value.s.rstrip()+post_hint
+            sentences[n] = Assign(targets=[target], value=help_str)
             # Copy the line number from the original docstring
+            copy_location(target, s)
             copy_location(sentences[n], s)
         prev = s
     # Return the modified AST
@@ -88,24 +93,13 @@ def _do_wrap_class_register(tree, mod, base_class):
     if isinstance(tree, ClassDef):
         # Create the register call
         name = tree.name
-        l_start = tree.lineno
-        # Python 3.8:
-        # l_end = tree.end_lineno
-        # Python 3.7, this is good enough for our needs:
-        l_end = l_start + 1
         reg_name = name.lower()
         # BaseOutput.register member:
         attr = Attribute(value=Name(id=base_class, ctx=Load()), attr='register', ctx=Load())
         # Function call to it passing reg_name and name
-        # Put it in the last line.
-        do_register = Expr(value=Call(func=attr, args=[Str(s=reg_name), Name(id=name, ctx=Load())], keywords=[]),
-                           lineno=l_end, col_offset=0, end_lineno=l_end, end_col_offset=50)
-
+        do_register = Expr(value=Call(func=attr, args=[Str(s=reg_name), Name(id=name, ctx=Load())], keywords=[]))
         # Create the import
-        # Put it in the decorator line.
-        do_import = ImportFrom(module=mod, names=[alias(name=base_class, asname=None)], level=1,
-                               lineno=l_start-1, col_offset=0, end_lineno=l_start-1, end_col_offset=50)
-
+        do_import = ImportFrom(module=mod, names=[alias(name=base_class, asname=None)], level=1)
         return [do_import, tree, do_register]
     # Just in case somebody applies it to anything other than a class
     return tree  # pragma: no cover
