@@ -3,10 +3,14 @@
 # Copyright (c) 2020 Instituto Nacional de Tecnología Industrial
 # License: GPL-3.0
 # Project: KiBot (formerly KiPlot)
-from pcbnew import EDGE_MODULE, wxPoint, LSET
 from .gs import GS
-from .misc import Rect
 from .kiplot import load_sch
+from .misc import Rect, KICAD_VERSION_5_99, W_WRONGPASTE
+if GS.kicad_version_n >= KICAD_VERSION_5_99:
+    # New name, no alias ...
+    from pcbnew import FP_SHAPE, wxPoint, LSET
+else:
+    from pcbnew import EDGE_MODULE, wxPoint, LSET
 from .registrable import RegOutput
 from .optionable import Optionable, BaseOptions
 from .fil_base import BaseFilter, apply_fitted_filter, reset_filters
@@ -105,19 +109,25 @@ class VariantOptions(BaseOptions):
             return []
         return [c.ref for c in self._comps if not c.fitted or not c.included]
 
+    @staticmethod
+    def create_module_element(m):
+        if GS.kicad_version_n >= KICAD_VERSION_5_99:
+            return FP_SHAPE(m)
+        return EDGE_MODULE(m)
+
     @staticmethod
     def cross_module(m, rect, layer):
         """ Draw a cross over a module.
             The rect is a Rect object with the size.
             The layer is which layer id will be used. """
-        seg1 = EDGE_MODULE(m)
+        seg1 = VariantOptions.create_module_element(m)
         seg1.SetWidth(120000)
         seg1.SetStart(wxPoint(rect.x1, rect.y1))
         seg1.SetEnd(wxPoint(rect.x2, rect.y2))
         seg1.SetLayer(layer)
         seg1.SetLocalCoord()  # Update the local coordinates
         m.Add(seg1)
-        seg2 = EDGE_MODULE(m)
+        seg2 = VariantOptions.create_module_element(m)
         seg2.SetWidth(120000)
         seg2.SetStart(wxPoint(rect.x1, rect.y2))
         seg2.SetEnd(wxPoint(rect.x2, rect.y1))
@@ -180,14 +190,18 @@ class VariantOptions(BaseOptions):
     def remove_paste_and_glue(self, board, comps_hash):
         """ Remove from solder paste layers the filtered components. """
         exclude = LSET()
-        exclude.addLayer(board.GetLayerID('F.Paste'))
-        exclude.addLayer(board.GetLayerID('B.Paste'))
+        fpaste = board.GetLayerID('F.Paste')
+        bpaste = board.GetLayerID('B.Paste')
+        exclude.addLayer(fpaste)
+        exclude.addLayer(bpaste)
         old_layers = []
         fadhes = board.GetLayerID('F.Adhes')
         badhes = board.GetLayerID('B.Adhes')
         old_fadhes = []
         old_badhes = []
         rescue = board.GetLayerID('Rescue')
+        fmask = board.GetLayerID('F.Mask')
+        bmask = board.GetLayerID('B.Mask')
         for m in board.GetModules():
             ref = m.GetReference()
             c = comps_hash.get(ref, None)
@@ -196,8 +210,14 @@ class VariantOptions(BaseOptions):
                 old_c_layers = []
                 for p in m.Pads():
                     pad_layers = p.GetLayerSet()
+                    is_front = fpaste in pad_layers.Seq()
                     old_c_layers.append(pad_layers.FmtHex())
                     pad_layers.removeLayerSet(exclude)
+                    if len(pad_layers.Seq()) == 0:
+                        # No layers at all. Ridiculous, but happends.
+                        # At least add an F.Mask
+                        pad_layers.addLayer(fmask if is_front else bmask)
+                        logger.warning(W_WRONGPASTE+'Pad with solder paste, but no copper or solder mask aperture in '+ref)
                     p.SetLayerSet(pad_layers)
                 old_layers.append(old_c_layers)
                 # Remove any graphical item in the *.Adhes layers
