@@ -19,9 +19,12 @@ from .bom.bom import do_bom
 from .var_kibom import KiBoM
 from .fil_base import BaseFilter, apply_exclude_filter, apply_fitted_filter, apply_fixed_filter, reset_filters
 from . import log
+# To debug the `with document` we can use:
+# from .mcpyrate.debug import macros, step_expansion
+# with step_expansion:
 
 logger = log.get_logger(__name__)
-VALID_STYLES = {'modern-blue': 1, 'modern-green': 1, 'modern-red': 1, 'classic': 1}
+VALID_STYLES = {'modern-blue', 'modern-green', 'modern-red', 'classic'}
 DEFAULT_ALIASES = [['r', 'r_small', 'res', 'resistor'],
                    ['l', 'l_small', 'inductor'],
                    ['c', 'c_small', 'cap', 'capacitor'],
@@ -201,6 +204,8 @@ class BoMOptions(BaseOptions):
             """ Try to normalize the R, L and C values, producing uniform units and prefixes """
             self.normalize_locale = False
             """ When normalizing values use the locale decimal point """
+            self.ref_separator = ' '
+            """ Separator used for the list of references """
             self.html = BoMHTML
             """ [dict] Options for the HTML format """
             self.xlsx = BoMXLSX
