@@ -8,6 +8,8 @@
 from pcbnew import (PLOT_FORMAT_PDF, FromMM, ToMM)
 from .out_any_layer import AnyLayer
 from .drill_marks import DrillMarks
+from .gs import GS
+from .misc import KICAD_VERSION_5_99
 from .macros import macros, document, output_class  # noqa: F401
 from . import log
 
@@ -19,7 +21,7 @@ class PDFOptions(DrillMarks):
         super().__init__()
         with document:
             self.line_width = 0.1
-            """ [0.02,2] for objects without width [mm] """
+            """ [0.02,2] for objects without width [mm] (KiCad 5) """
             self.mirror_plot = False
             """ plot mirrored """
             self.negative_plot = False
@@ -29,13 +31,15 @@ class PDFOptions(DrillMarks):
     def _configure_plot_ctrl(self, po, output_dir):
         super()._configure_plot_ctrl(po, output_dir)
         po.SetMirror(self.mirror_plot)
-        po.SetLineWidth(FromMM(self.line_width))
+        if GS.kicad_version_n < KICAD_VERSION_5_99:
+            po.SetLineWidth(FromMM(self.line_width))
         po.SetNegative(self.negative_plot)
 
     def read_vals_from_po(self, po):
         super().read_vals_from_po(po)
         self.mirror_plot = po.GetMirror()
-        self.line_width = ToMM(po.GetLineWidth())
+        if GS.kicad_version_n < KICAD_VERSION_5_99:
+            self.line_width = ToMM(po.GetLineWidth())
         self.negative_plot = po.GetNegative()
 
 
